# IO.Swagger - the C# library for the App Weather - A Weather Source API

App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- SDK version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.dotnet.CSharpClientCodegen
    For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            // Configure API key authorization: ApiKeyAuth
            Configuration.Default.ApiKey.Add("X-API-KEY", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("X-API-KEY", "Bearer");

            var apiInstance = new OnpointsApi();
            var onpointId = 56;  // int? | An OnPoint™ ID.
            var services = new List<string>(); // List<string> | A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** 
            var fields = new List<string>(); // List<string> | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** 
            var unitScale = unitScale_example;  // string | The unit scale for returned values.<br> (optional)  (default to IMPERIAL)
            var language = language_example;  // string | The language for translatable returned values.<br> (optional)  (default to ENGLISH)

            try
            {
                // App Weather for an OnPoint™ point.
                AppwxOnpointObj result = apiInstance.OnpointsOnpointIdGet(onpointId, services, fields, unitScale, language);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling OnpointsApi.OnpointsOnpointIdGet: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://appwx.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*OnpointsApi* | [**OnpointsOnpointIdGet**](docs/OnpointsApi.md#onpointsonpointidget) | **GET** /onpoints/{onpointId} | App Weather for an OnPoint™ point.
*PointsApi* | [**PointsLatitudelongitudeGet**](docs/PointsApi.md#pointslatitudelongitudeget) | **GET** /points/{latitude},{longitude} | App Weather for a Latitude/Longitude point.
*PostcodesApi* | [**PostcodesPostcodecountryCodeGet**](docs/PostcodesApi.md#postcodespostcodecountrycodeget) | **GET** /postcodes/{postcode},{countryCode} | App Weather response for a postcode.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.AppwxOnpointObj](docs/AppwxOnpointObj.md)
 - [Model.AppwxPointObj](docs/AppwxPointObj.md)
 - [Model.AppwxPostcodeObj](docs/AppwxPostcodeObj.md)
 - [Model.BoundingPoints](docs/BoundingPoints.md)
 - [Model.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [Model.ErrorObj](docs/ErrorObj.md)
 - [Model.FeaturesObj](docs/FeaturesObj.md)
 - [Model.FieldListObj](docs/FieldListObj.md)
 - [Model.Fields](docs/Fields.md)
 - [Model.ForecastDayArr](docs/ForecastDayArr.md)
 - [Model.ForecastDayObj](docs/ForecastDayObj.md)
 - [Model.ForecastHourArr](docs/ForecastHourArr.md)
 - [Model.ForecastHourObj](docs/ForecastHourObj.md)
 - [Model.Grid](docs/Grid.md)
 - [Model.Language](docs/Language.md)
 - [Model.NowcastObj](docs/NowcastObj.md)
 - [Model.OnpointObj](docs/OnpointObj.md)
 - [Model.PointObj](docs/PointObj.md)
 - [Model.PostcodeObj](docs/PostcodeObj.md)
 - [Model.UnitScale](docs/UnitScale.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header

