/* 
 * App Weather - A Weather Source API
 *
 * App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public interface IPostcodesApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// App Weather response for a postcode.
        /// </summary>
        /// <remarks>
        /// Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>AppwxPostcodeObj</returns>
        AppwxPostcodeObj PostcodesPostcodecountryCodeGet (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null);

        /// <summary>
        /// App Weather response for a postcode.
        /// </summary>
        /// <remarks>
        /// Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>ApiResponse of AppwxPostcodeObj</returns>
        ApiResponse<AppwxPostcodeObj> PostcodesPostcodecountryCodeGetWithHttpInfo (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// App Weather response for a postcode.
        /// </summary>
        /// <remarks>
        /// Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>Task of AppwxPostcodeObj</returns>
        System.Threading.Tasks.Task<AppwxPostcodeObj> PostcodesPostcodecountryCodeGetAsync (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null);

        /// <summary>
        /// App Weather response for a postcode.
        /// </summary>
        /// <remarks>
        /// Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>Task of ApiResponse (AppwxPostcodeObj)</returns>
        System.Threading.Tasks.Task<ApiResponse<AppwxPostcodeObj>> PostcodesPostcodecountryCodeGetAsyncWithHttpInfo (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public partial class PostcodesApi : IPostcodesApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public PostcodesApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class
        /// </summary>
        /// <returns></returns>
        public PostcodesApi()
        {
            this.Configuration = IO.Swagger.Client.Configuration.Default;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public PostcodesApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// App Weather response for a postcode. Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>AppwxPostcodeObj</returns>
        public AppwxPostcodeObj PostcodesPostcodecountryCodeGet (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null)
        {
             ApiResponse<AppwxPostcodeObj> localVarResponse = PostcodesPostcodecountryCodeGetWithHttpInfo(postcode, countryCode, services, fields, unitScale, language);
             return localVarResponse.Data;
        }

        /// <summary>
        /// App Weather response for a postcode. Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>ApiResponse of AppwxPostcodeObj</returns>
        public ApiResponse< AppwxPostcodeObj > PostcodesPostcodecountryCodeGetWithHttpInfo (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null)
        {
            // verify the required parameter 'postcode' is set
            if (postcode == null)
                throw new ApiException(400, "Missing required parameter 'postcode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'countryCode' is set
            if (countryCode == null)
                throw new ApiException(400, "Missing required parameter 'countryCode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'services' is set
            if (services == null)
                throw new ApiException(400, "Missing required parameter 'services' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'fields' is set
            if (fields == null)
                throw new ApiException(400, "Missing required parameter 'fields' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");

            var localVarPath = "/postcodes/{postcode},{countryCode}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (postcode != null) localVarPathParams.Add("postcode", this.Configuration.ApiClient.ParameterToString(postcode)); // path parameter
            if (countryCode != null) localVarPathParams.Add("countryCode", this.Configuration.ApiClient.ParameterToString(countryCode)); // path parameter
            if (services != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "services", services)); // query parameter
            if (fields != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "fields", fields)); // query parameter
            if (unitScale != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "unitScale", unitScale)); // query parameter
            if (language != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "language", language)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostcodesPostcodecountryCodeGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<AppwxPostcodeObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (AppwxPostcodeObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(AppwxPostcodeObj)));
        }

        /// <summary>
        /// App Weather response for a postcode. Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>Task of AppwxPostcodeObj</returns>
        public async System.Threading.Tasks.Task<AppwxPostcodeObj> PostcodesPostcodecountryCodeGetAsync (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null)
        {
             ApiResponse<AppwxPostcodeObj> localVarResponse = await PostcodesPostcodecountryCodeGetAsyncWithHttpInfo(postcode, countryCode, services, fields, unitScale, language);
             return localVarResponse.Data;

        }

        /// <summary>
        /// App Weather response for a postcode. Returns select nowcast and forecast (7-day - daily and hourly) data for a postcode.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.  **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <param name="services">A comma separated list of service names to return.  **Limiting the query to needed services will improve the query response time.** </param>
        /// <param name="fields">A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.** </param>
        /// <param name="unitScale">The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)</param>
        /// <param name="language">The language for translatable returned values.&lt;br&gt; (optional, default to ENGLISH)</param>
        /// <returns>Task of ApiResponse (AppwxPostcodeObj)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<AppwxPostcodeObj>> PostcodesPostcodecountryCodeGetAsyncWithHttpInfo (string postcode, string countryCode, List<string> services, List<string> fields, string unitScale = null, string language = null)
        {
            // verify the required parameter 'postcode' is set
            if (postcode == null)
                throw new ApiException(400, "Missing required parameter 'postcode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'countryCode' is set
            if (countryCode == null)
                throw new ApiException(400, "Missing required parameter 'countryCode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'services' is set
            if (services == null)
                throw new ApiException(400, "Missing required parameter 'services' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'fields' is set
            if (fields == null)
                throw new ApiException(400, "Missing required parameter 'fields' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");

            var localVarPath = "/postcodes/{postcode},{countryCode}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (postcode != null) localVarPathParams.Add("postcode", this.Configuration.ApiClient.ParameterToString(postcode)); // path parameter
            if (countryCode != null) localVarPathParams.Add("countryCode", this.Configuration.ApiClient.ParameterToString(countryCode)); // path parameter
            if (services != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "services", services)); // query parameter
            if (fields != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("csv", "fields", fields)); // query parameter
            if (unitScale != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "unitScale", unitScale)); // query parameter
            if (language != null) localVarQueryParams.AddRange(this.Configuration.ApiClient.ParameterToKeyValuePairs("", "language", language)); // query parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostcodesPostcodecountryCodeGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<AppwxPostcodeObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (AppwxPostcodeObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(AppwxPostcodeObj)));
        }

    }
}
