/* 
 * App Weather - A Weather Source API
 *
 * App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = IO.Swagger.Client.SwaggerDateConverter;

namespace IO.Swagger.Model
{
    /// <summary>
    /// OnPoint™ point App Weather object
    /// </summary>
    [DataContract]
        public partial class AppwxOnpointObj :  IEquatable<AppwxOnpointObj>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="AppwxOnpointObj" /> class.
        /// </summary>
        /// <param name="location">location (required).</param>
        /// <param name="features">features (required).</param>
        /// <param name="nowcast">nowcast (required).</param>
        /// <param name="forecastDay">forecastDay (required).</param>
        /// <param name="forecastHour">forecastHour (required).</param>
        public AppwxOnpointObj(OnpointObj location = default(OnpointObj), FeaturesObj features = default(FeaturesObj), NowcastObj nowcast = default(NowcastObj), ForecastDayArr forecastDay = default(ForecastDayArr), ForecastHourArr forecastHour = default(ForecastHourArr))
        {
            // to ensure "location" is required (not null)
            if (location == null)
            {
                throw new InvalidDataException("location is a required property for AppwxOnpointObj and cannot be null");
            }
            else
            {
                this.Location = location;
            }
            // to ensure "features" is required (not null)
            if (features == null)
            {
                throw new InvalidDataException("features is a required property for AppwxOnpointObj and cannot be null");
            }
            else
            {
                this.Features = features;
            }
            // to ensure "nowcast" is required (not null)
            if (nowcast == null)
            {
                throw new InvalidDataException("nowcast is a required property for AppwxOnpointObj and cannot be null");
            }
            else
            {
                this.Nowcast = nowcast;
            }
            // to ensure "forecastDay" is required (not null)
            if (forecastDay == null)
            {
                throw new InvalidDataException("forecastDay is a required property for AppwxOnpointObj and cannot be null");
            }
            else
            {
                this.ForecastDay = forecastDay;
            }
            // to ensure "forecastHour" is required (not null)
            if (forecastHour == null)
            {
                throw new InvalidDataException("forecastHour is a required property for AppwxOnpointObj and cannot be null");
            }
            else
            {
                this.ForecastHour = forecastHour;
            }
        }
        
        /// <summary>
        /// Gets or Sets Location
        /// </summary>
        [DataMember(Name="location", EmitDefaultValue=false)]
        public OnpointObj Location { get; set; }

        /// <summary>
        /// Gets or Sets Features
        /// </summary>
        [DataMember(Name="features", EmitDefaultValue=false)]
        public FeaturesObj Features { get; set; }

        /// <summary>
        /// Gets or Sets Nowcast
        /// </summary>
        [DataMember(Name="nowcast", EmitDefaultValue=false)]
        public NowcastObj Nowcast { get; set; }

        /// <summary>
        /// Gets or Sets ForecastDay
        /// </summary>
        [DataMember(Name="forecastDay", EmitDefaultValue=false)]
        public ForecastDayArr ForecastDay { get; set; }

        /// <summary>
        /// Gets or Sets ForecastHour
        /// </summary>
        [DataMember(Name="forecastHour", EmitDefaultValue=false)]
        public ForecastHourArr ForecastHour { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class AppwxOnpointObj {\n");
            sb.Append("  Location: ").Append(Location).Append("\n");
            sb.Append("  Features: ").Append(Features).Append("\n");
            sb.Append("  Nowcast: ").Append(Nowcast).Append("\n");
            sb.Append("  ForecastDay: ").Append(ForecastDay).Append("\n");
            sb.Append("  ForecastHour: ").Append(ForecastHour).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as AppwxOnpointObj);
        }

        /// <summary>
        /// Returns true if AppwxOnpointObj instances are equal
        /// </summary>
        /// <param name="input">Instance of AppwxOnpointObj to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(AppwxOnpointObj input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Location == input.Location ||
                    (this.Location != null &&
                    this.Location.Equals(input.Location))
                ) && 
                (
                    this.Features == input.Features ||
                    (this.Features != null &&
                    this.Features.Equals(input.Features))
                ) && 
                (
                    this.Nowcast == input.Nowcast ||
                    (this.Nowcast != null &&
                    this.Nowcast.Equals(input.Nowcast))
                ) && 
                (
                    this.ForecastDay == input.ForecastDay ||
                    (this.ForecastDay != null &&
                    this.ForecastDay.Equals(input.ForecastDay))
                ) && 
                (
                    this.ForecastHour == input.ForecastHour ||
                    (this.ForecastHour != null &&
                    this.ForecastHour.Equals(input.ForecastHour))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Location != null)
                    hashCode = hashCode * 59 + this.Location.GetHashCode();
                if (this.Features != null)
                    hashCode = hashCode * 59 + this.Features.GetHashCode();
                if (this.Nowcast != null)
                    hashCode = hashCode * 59 + this.Nowcast.GetHashCode();
                if (this.ForecastDay != null)
                    hashCode = hashCode * 59 + this.ForecastDay.GetHashCode();
                if (this.ForecastHour != null)
                    hashCode = hashCode * 59 + this.ForecastHour.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
