/* 
 * App Weather - A Weather Source API
 *
 * App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = IO.Swagger.Client.SwaggerDateConverter;

namespace IO.Swagger.Model
{
    /// <summary>
    /// An hourly weather forecast object.
    /// </summary>
    [DataContract]
        public partial class ForecastHourObj :  IEquatable<ForecastHourObj>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ForecastHourObj" /> class.
        /// </summary>
        /// <param name="timestamp">timestamp (required).</param>
        /// <param name="cldCvr">cldCvr.</param>
        /// <param name="feelsLike">feelsLike.</param>
        /// <param name="icon">icon.</param>
        /// <param name="precip">precip.</param>
        /// <param name="precipProb">precipProb.</param>
        /// <param name="relHum">relHum.</param>
        /// <param name="snowfall">snowfall.</param>
        /// <param name="snowfallProb">snowfallProb.</param>
        /// <param name="summary">summary.</param>
        /// <param name="temp">temp.</param>
        /// <param name="windDir">windDir.</param>
        /// <param name="windSpd">windSpd.</param>
        public ForecastHourObj(DateTime? timestamp = default(DateTime?), float? cldCvr = default(float?), float? feelsLike = default(float?), string icon = default(string), float? precip = default(float?), float? precipProb = default(float?), float? relHum = default(float?), float? snowfall = default(float?), float? snowfallProb = default(float?), string summary = default(string), float? temp = default(float?), string windDir = default(string), float? windSpd = default(float?))
        {
            // to ensure "timestamp" is required (not null)
            if (timestamp == null)
            {
                throw new InvalidDataException("timestamp is a required property for ForecastHourObj and cannot be null");
            }
            else
            {
                this.Timestamp = timestamp;
            }
            this.CldCvr = cldCvr;
            this.FeelsLike = feelsLike;
            this.Icon = icon;
            this.Precip = precip;
            this.PrecipProb = precipProb;
            this.RelHum = relHum;
            this.Snowfall = snowfall;
            this.SnowfallProb = snowfallProb;
            this.Summary = summary;
            this.Temp = temp;
            this.WindDir = windDir;
            this.WindSpd = windSpd;
        }
        
        /// <summary>
        /// Gets or Sets Timestamp
        /// </summary>
        [DataMember(Name="timestamp", EmitDefaultValue=false)]
        public DateTime? Timestamp { get; set; }

        /// <summary>
        /// Gets or Sets CldCvr
        /// </summary>
        [DataMember(Name="cldCvr", EmitDefaultValue=false)]
        public float? CldCvr { get; set; }

        /// <summary>
        /// Gets or Sets FeelsLike
        /// </summary>
        [DataMember(Name="feelsLike", EmitDefaultValue=false)]
        public float? FeelsLike { get; set; }

        /// <summary>
        /// Gets or Sets Icon
        /// </summary>
        [DataMember(Name="icon", EmitDefaultValue=false)]
        public string Icon { get; set; }

        /// <summary>
        /// Gets or Sets Precip
        /// </summary>
        [DataMember(Name="precip", EmitDefaultValue=false)]
        public float? Precip { get; set; }

        /// <summary>
        /// Gets or Sets PrecipProb
        /// </summary>
        [DataMember(Name="precipProb", EmitDefaultValue=false)]
        public float? PrecipProb { get; set; }

        /// <summary>
        /// Gets or Sets RelHum
        /// </summary>
        [DataMember(Name="relHum", EmitDefaultValue=false)]
        public float? RelHum { get; set; }

        /// <summary>
        /// Gets or Sets Snowfall
        /// </summary>
        [DataMember(Name="snowfall", EmitDefaultValue=false)]
        public float? Snowfall { get; set; }

        /// <summary>
        /// Gets or Sets SnowfallProb
        /// </summary>
        [DataMember(Name="snowfallProb", EmitDefaultValue=false)]
        public float? SnowfallProb { get; set; }

        /// <summary>
        /// Gets or Sets Summary
        /// </summary>
        [DataMember(Name="summary", EmitDefaultValue=false)]
        public string Summary { get; set; }

        /// <summary>
        /// Gets or Sets Temp
        /// </summary>
        [DataMember(Name="temp", EmitDefaultValue=false)]
        public float? Temp { get; set; }

        /// <summary>
        /// Gets or Sets WindDir
        /// </summary>
        [DataMember(Name="windDir", EmitDefaultValue=false)]
        public string WindDir { get; set; }

        /// <summary>
        /// Gets or Sets WindSpd
        /// </summary>
        [DataMember(Name="windSpd", EmitDefaultValue=false)]
        public float? WindSpd { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class ForecastHourObj {\n");
            sb.Append("  Timestamp: ").Append(Timestamp).Append("\n");
            sb.Append("  CldCvr: ").Append(CldCvr).Append("\n");
            sb.Append("  FeelsLike: ").Append(FeelsLike).Append("\n");
            sb.Append("  Icon: ").Append(Icon).Append("\n");
            sb.Append("  Precip: ").Append(Precip).Append("\n");
            sb.Append("  PrecipProb: ").Append(PrecipProb).Append("\n");
            sb.Append("  RelHum: ").Append(RelHum).Append("\n");
            sb.Append("  Snowfall: ").Append(Snowfall).Append("\n");
            sb.Append("  SnowfallProb: ").Append(SnowfallProb).Append("\n");
            sb.Append("  Summary: ").Append(Summary).Append("\n");
            sb.Append("  Temp: ").Append(Temp).Append("\n");
            sb.Append("  WindDir: ").Append(WindDir).Append("\n");
            sb.Append("  WindSpd: ").Append(WindSpd).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as ForecastHourObj);
        }

        /// <summary>
        /// Returns true if ForecastHourObj instances are equal
        /// </summary>
        /// <param name="input">Instance of ForecastHourObj to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(ForecastHourObj input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Timestamp == input.Timestamp ||
                    (this.Timestamp != null &&
                    this.Timestamp.Equals(input.Timestamp))
                ) && 
                (
                    this.CldCvr == input.CldCvr ||
                    (this.CldCvr != null &&
                    this.CldCvr.Equals(input.CldCvr))
                ) && 
                (
                    this.FeelsLike == input.FeelsLike ||
                    (this.FeelsLike != null &&
                    this.FeelsLike.Equals(input.FeelsLike))
                ) && 
                (
                    this.Icon == input.Icon ||
                    (this.Icon != null &&
                    this.Icon.Equals(input.Icon))
                ) && 
                (
                    this.Precip == input.Precip ||
                    (this.Precip != null &&
                    this.Precip.Equals(input.Precip))
                ) && 
                (
                    this.PrecipProb == input.PrecipProb ||
                    (this.PrecipProb != null &&
                    this.PrecipProb.Equals(input.PrecipProb))
                ) && 
                (
                    this.RelHum == input.RelHum ||
                    (this.RelHum != null &&
                    this.RelHum.Equals(input.RelHum))
                ) && 
                (
                    this.Snowfall == input.Snowfall ||
                    (this.Snowfall != null &&
                    this.Snowfall.Equals(input.Snowfall))
                ) && 
                (
                    this.SnowfallProb == input.SnowfallProb ||
                    (this.SnowfallProb != null &&
                    this.SnowfallProb.Equals(input.SnowfallProb))
                ) && 
                (
                    this.Summary == input.Summary ||
                    (this.Summary != null &&
                    this.Summary.Equals(input.Summary))
                ) && 
                (
                    this.Temp == input.Temp ||
                    (this.Temp != null &&
                    this.Temp.Equals(input.Temp))
                ) && 
                (
                    this.WindDir == input.WindDir ||
                    (this.WindDir != null &&
                    this.WindDir.Equals(input.WindDir))
                ) && 
                (
                    this.WindSpd == input.WindSpd ||
                    (this.WindSpd != null &&
                    this.WindSpd.Equals(input.WindSpd))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Timestamp != null)
                    hashCode = hashCode * 59 + this.Timestamp.GetHashCode();
                if (this.CldCvr != null)
                    hashCode = hashCode * 59 + this.CldCvr.GetHashCode();
                if (this.FeelsLike != null)
                    hashCode = hashCode * 59 + this.FeelsLike.GetHashCode();
                if (this.Icon != null)
                    hashCode = hashCode * 59 + this.Icon.GetHashCode();
                if (this.Precip != null)
                    hashCode = hashCode * 59 + this.Precip.GetHashCode();
                if (this.PrecipProb != null)
                    hashCode = hashCode * 59 + this.PrecipProb.GetHashCode();
                if (this.RelHum != null)
                    hashCode = hashCode * 59 + this.RelHum.GetHashCode();
                if (this.Snowfall != null)
                    hashCode = hashCode * 59 + this.Snowfall.GetHashCode();
                if (this.SnowfallProb != null)
                    hashCode = hashCode * 59 + this.SnowfallProb.GetHashCode();
                if (this.Summary != null)
                    hashCode = hashCode * 59 + this.Summary.GetHashCode();
                if (this.Temp != null)
                    hashCode = hashCode * 59 + this.Temp.GetHashCode();
                if (this.WindDir != null)
                    hashCode = hashCode * 59 + this.WindDir.GetHashCode();
                if (this.WindSpd != null)
                    hashCode = hashCode * 59 + this.WindSpd.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
