/* 
 * App Weather - A Weather Source API
 *
 * App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = IO.Swagger.Client.SwaggerDateConverter;

namespace IO.Swagger.Model
{
    /// <summary>
    /// A nowcast object.
    /// </summary>
    [DataContract]
        public partial class NowcastObj :  IEquatable<NowcastObj>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="NowcastObj" /> class.
        /// </summary>
        /// <param name="timestamp">timestamp (required).</param>
        /// <param name="civilRise">civilRise.</param>
        /// <param name="civilSet">civilSet.</param>
        /// <param name="cldCvr">cldCvr.</param>
        /// <param name="feelsLike">feelsLike.</param>
        /// <param name="icon">icon.</param>
        /// <param name="moonPhase">moonPhase.</param>
        /// <param name="precipFlag">precipFlag.</param>
        /// <param name="precipIntensity">precipIntensity.</param>
        /// <param name="relHum">relHum.</param>
        /// <param name="snowfallFlag">snowfallFlag.</param>
        /// <param name="snowfallIntensity">snowfallIntensity.</param>
        /// <param name="summary">summary.</param>
        /// <param name="summaryLong">summaryLong.</param>
        /// <param name="sunTransit">sunTransit.</param>
        /// <param name="sunrise">sunrise.</param>
        /// <param name="sunset">sunset.</param>
        /// <param name="temp">temp.</param>
        /// <param name="tempMax">tempMax.</param>
        /// <param name="tempMin">tempMin.</param>
        /// <param name="windDir">windDir.</param>
        /// <param name="windSpd">windSpd.</param>
        public NowcastObj(DateTime? timestamp = default(DateTime?), DateTime? civilRise = default(DateTime?), DateTime? civilSet = default(DateTime?), float? cldCvr = default(float?), float? feelsLike = default(float?), string icon = default(string), string moonPhase = default(string), bool? precipFlag = default(bool?), float? precipIntensity = default(float?), float? relHum = default(float?), bool? snowfallFlag = default(bool?), float? snowfallIntensity = default(float?), string summary = default(string), string summaryLong = default(string), DateTime? sunTransit = default(DateTime?), DateTime? sunrise = default(DateTime?), DateTime? sunset = default(DateTime?), float? temp = default(float?), float? tempMax = default(float?), float? tempMin = default(float?), string windDir = default(string), float? windSpd = default(float?))
        {
            // to ensure "timestamp" is required (not null)
            if (timestamp == null)
            {
                throw new InvalidDataException("timestamp is a required property for NowcastObj and cannot be null");
            }
            else
            {
                this.Timestamp = timestamp;
            }
            this.CivilRise = civilRise;
            this.CivilSet = civilSet;
            this.CldCvr = cldCvr;
            this.FeelsLike = feelsLike;
            this.Icon = icon;
            this.MoonPhase = moonPhase;
            this.PrecipFlag = precipFlag;
            this.PrecipIntensity = precipIntensity;
            this.RelHum = relHum;
            this.SnowfallFlag = snowfallFlag;
            this.SnowfallIntensity = snowfallIntensity;
            this.Summary = summary;
            this.SummaryLong = summaryLong;
            this.SunTransit = sunTransit;
            this.Sunrise = sunrise;
            this.Sunset = sunset;
            this.Temp = temp;
            this.TempMax = tempMax;
            this.TempMin = tempMin;
            this.WindDir = windDir;
            this.WindSpd = windSpd;
        }
        
        /// <summary>
        /// Gets or Sets Timestamp
        /// </summary>
        [DataMember(Name="timestamp", EmitDefaultValue=false)]
        public DateTime? Timestamp { get; set; }

        /// <summary>
        /// Gets or Sets CivilRise
        /// </summary>
        [DataMember(Name="civilRise", EmitDefaultValue=false)]
        public DateTime? CivilRise { get; set; }

        /// <summary>
        /// Gets or Sets CivilSet
        /// </summary>
        [DataMember(Name="civilSet", EmitDefaultValue=false)]
        public DateTime? CivilSet { get; set; }

        /// <summary>
        /// Gets or Sets CldCvr
        /// </summary>
        [DataMember(Name="cldCvr", EmitDefaultValue=false)]
        public float? CldCvr { get; set; }

        /// <summary>
        /// Gets or Sets FeelsLike
        /// </summary>
        [DataMember(Name="feelsLike", EmitDefaultValue=false)]
        public float? FeelsLike { get; set; }

        /// <summary>
        /// Gets or Sets Icon
        /// </summary>
        [DataMember(Name="icon", EmitDefaultValue=false)]
        public string Icon { get; set; }

        /// <summary>
        /// Gets or Sets MoonPhase
        /// </summary>
        [DataMember(Name="moonPhase", EmitDefaultValue=false)]
        public string MoonPhase { get; set; }

        /// <summary>
        /// Gets or Sets PrecipFlag
        /// </summary>
        [DataMember(Name="precipFlag", EmitDefaultValue=false)]
        public bool? PrecipFlag { get; set; }

        /// <summary>
        /// Gets or Sets PrecipIntensity
        /// </summary>
        [DataMember(Name="precipIntensity", EmitDefaultValue=false)]
        public float? PrecipIntensity { get; set; }

        /// <summary>
        /// Gets or Sets RelHum
        /// </summary>
        [DataMember(Name="relHum", EmitDefaultValue=false)]
        public float? RelHum { get; set; }

        /// <summary>
        /// Gets or Sets SnowfallFlag
        /// </summary>
        [DataMember(Name="snowfallFlag", EmitDefaultValue=false)]
        public bool? SnowfallFlag { get; set; }

        /// <summary>
        /// Gets or Sets SnowfallIntensity
        /// </summary>
        [DataMember(Name="snowfallIntensity", EmitDefaultValue=false)]
        public float? SnowfallIntensity { get; set; }

        /// <summary>
        /// Gets or Sets Summary
        /// </summary>
        [DataMember(Name="summary", EmitDefaultValue=false)]
        public string Summary { get; set; }

        /// <summary>
        /// Gets or Sets SummaryLong
        /// </summary>
        [DataMember(Name="summaryLong", EmitDefaultValue=false)]
        public string SummaryLong { get; set; }

        /// <summary>
        /// Gets or Sets SunTransit
        /// </summary>
        [DataMember(Name="sunTransit", EmitDefaultValue=false)]
        public DateTime? SunTransit { get; set; }

        /// <summary>
        /// Gets or Sets Sunrise
        /// </summary>
        [DataMember(Name="sunrise", EmitDefaultValue=false)]
        public DateTime? Sunrise { get; set; }

        /// <summary>
        /// Gets or Sets Sunset
        /// </summary>
        [DataMember(Name="sunset", EmitDefaultValue=false)]
        public DateTime? Sunset { get; set; }

        /// <summary>
        /// Gets or Sets Temp
        /// </summary>
        [DataMember(Name="temp", EmitDefaultValue=false)]
        public float? Temp { get; set; }

        /// <summary>
        /// Gets or Sets TempMax
        /// </summary>
        [DataMember(Name="tempMax", EmitDefaultValue=false)]
        public float? TempMax { get; set; }

        /// <summary>
        /// Gets or Sets TempMin
        /// </summary>
        [DataMember(Name="tempMin", EmitDefaultValue=false)]
        public float? TempMin { get; set; }

        /// <summary>
        /// Gets or Sets WindDir
        /// </summary>
        [DataMember(Name="windDir", EmitDefaultValue=false)]
        public string WindDir { get; set; }

        /// <summary>
        /// Gets or Sets WindSpd
        /// </summary>
        [DataMember(Name="windSpd", EmitDefaultValue=false)]
        public float? WindSpd { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class NowcastObj {\n");
            sb.Append("  Timestamp: ").Append(Timestamp).Append("\n");
            sb.Append("  CivilRise: ").Append(CivilRise).Append("\n");
            sb.Append("  CivilSet: ").Append(CivilSet).Append("\n");
            sb.Append("  CldCvr: ").Append(CldCvr).Append("\n");
            sb.Append("  FeelsLike: ").Append(FeelsLike).Append("\n");
            sb.Append("  Icon: ").Append(Icon).Append("\n");
            sb.Append("  MoonPhase: ").Append(MoonPhase).Append("\n");
            sb.Append("  PrecipFlag: ").Append(PrecipFlag).Append("\n");
            sb.Append("  PrecipIntensity: ").Append(PrecipIntensity).Append("\n");
            sb.Append("  RelHum: ").Append(RelHum).Append("\n");
            sb.Append("  SnowfallFlag: ").Append(SnowfallFlag).Append("\n");
            sb.Append("  SnowfallIntensity: ").Append(SnowfallIntensity).Append("\n");
            sb.Append("  Summary: ").Append(Summary).Append("\n");
            sb.Append("  SummaryLong: ").Append(SummaryLong).Append("\n");
            sb.Append("  SunTransit: ").Append(SunTransit).Append("\n");
            sb.Append("  Sunrise: ").Append(Sunrise).Append("\n");
            sb.Append("  Sunset: ").Append(Sunset).Append("\n");
            sb.Append("  Temp: ").Append(Temp).Append("\n");
            sb.Append("  TempMax: ").Append(TempMax).Append("\n");
            sb.Append("  TempMin: ").Append(TempMin).Append("\n");
            sb.Append("  WindDir: ").Append(WindDir).Append("\n");
            sb.Append("  WindSpd: ").Append(WindSpd).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as NowcastObj);
        }

        /// <summary>
        /// Returns true if NowcastObj instances are equal
        /// </summary>
        /// <param name="input">Instance of NowcastObj to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(NowcastObj input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Timestamp == input.Timestamp ||
                    (this.Timestamp != null &&
                    this.Timestamp.Equals(input.Timestamp))
                ) && 
                (
                    this.CivilRise == input.CivilRise ||
                    (this.CivilRise != null &&
                    this.CivilRise.Equals(input.CivilRise))
                ) && 
                (
                    this.CivilSet == input.CivilSet ||
                    (this.CivilSet != null &&
                    this.CivilSet.Equals(input.CivilSet))
                ) && 
                (
                    this.CldCvr == input.CldCvr ||
                    (this.CldCvr != null &&
                    this.CldCvr.Equals(input.CldCvr))
                ) && 
                (
                    this.FeelsLike == input.FeelsLike ||
                    (this.FeelsLike != null &&
                    this.FeelsLike.Equals(input.FeelsLike))
                ) && 
                (
                    this.Icon == input.Icon ||
                    (this.Icon != null &&
                    this.Icon.Equals(input.Icon))
                ) && 
                (
                    this.MoonPhase == input.MoonPhase ||
                    (this.MoonPhase != null &&
                    this.MoonPhase.Equals(input.MoonPhase))
                ) && 
                (
                    this.PrecipFlag == input.PrecipFlag ||
                    (this.PrecipFlag != null &&
                    this.PrecipFlag.Equals(input.PrecipFlag))
                ) && 
                (
                    this.PrecipIntensity == input.PrecipIntensity ||
                    (this.PrecipIntensity != null &&
                    this.PrecipIntensity.Equals(input.PrecipIntensity))
                ) && 
                (
                    this.RelHum == input.RelHum ||
                    (this.RelHum != null &&
                    this.RelHum.Equals(input.RelHum))
                ) && 
                (
                    this.SnowfallFlag == input.SnowfallFlag ||
                    (this.SnowfallFlag != null &&
                    this.SnowfallFlag.Equals(input.SnowfallFlag))
                ) && 
                (
                    this.SnowfallIntensity == input.SnowfallIntensity ||
                    (this.SnowfallIntensity != null &&
                    this.SnowfallIntensity.Equals(input.SnowfallIntensity))
                ) && 
                (
                    this.Summary == input.Summary ||
                    (this.Summary != null &&
                    this.Summary.Equals(input.Summary))
                ) && 
                (
                    this.SummaryLong == input.SummaryLong ||
                    (this.SummaryLong != null &&
                    this.SummaryLong.Equals(input.SummaryLong))
                ) && 
                (
                    this.SunTransit == input.SunTransit ||
                    (this.SunTransit != null &&
                    this.SunTransit.Equals(input.SunTransit))
                ) && 
                (
                    this.Sunrise == input.Sunrise ||
                    (this.Sunrise != null &&
                    this.Sunrise.Equals(input.Sunrise))
                ) && 
                (
                    this.Sunset == input.Sunset ||
                    (this.Sunset != null &&
                    this.Sunset.Equals(input.Sunset))
                ) && 
                (
                    this.Temp == input.Temp ||
                    (this.Temp != null &&
                    this.Temp.Equals(input.Temp))
                ) && 
                (
                    this.TempMax == input.TempMax ||
                    (this.TempMax != null &&
                    this.TempMax.Equals(input.TempMax))
                ) && 
                (
                    this.TempMin == input.TempMin ||
                    (this.TempMin != null &&
                    this.TempMin.Equals(input.TempMin))
                ) && 
                (
                    this.WindDir == input.WindDir ||
                    (this.WindDir != null &&
                    this.WindDir.Equals(input.WindDir))
                ) && 
                (
                    this.WindSpd == input.WindSpd ||
                    (this.WindSpd != null &&
                    this.WindSpd.Equals(input.WindSpd))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Timestamp != null)
                    hashCode = hashCode * 59 + this.Timestamp.GetHashCode();
                if (this.CivilRise != null)
                    hashCode = hashCode * 59 + this.CivilRise.GetHashCode();
                if (this.CivilSet != null)
                    hashCode = hashCode * 59 + this.CivilSet.GetHashCode();
                if (this.CldCvr != null)
                    hashCode = hashCode * 59 + this.CldCvr.GetHashCode();
                if (this.FeelsLike != null)
                    hashCode = hashCode * 59 + this.FeelsLike.GetHashCode();
                if (this.Icon != null)
                    hashCode = hashCode * 59 + this.Icon.GetHashCode();
                if (this.MoonPhase != null)
                    hashCode = hashCode * 59 + this.MoonPhase.GetHashCode();
                if (this.PrecipFlag != null)
                    hashCode = hashCode * 59 + this.PrecipFlag.GetHashCode();
                if (this.PrecipIntensity != null)
                    hashCode = hashCode * 59 + this.PrecipIntensity.GetHashCode();
                if (this.RelHum != null)
                    hashCode = hashCode * 59 + this.RelHum.GetHashCode();
                if (this.SnowfallFlag != null)
                    hashCode = hashCode * 59 + this.SnowfallFlag.GetHashCode();
                if (this.SnowfallIntensity != null)
                    hashCode = hashCode * 59 + this.SnowfallIntensity.GetHashCode();
                if (this.Summary != null)
                    hashCode = hashCode * 59 + this.Summary.GetHashCode();
                if (this.SummaryLong != null)
                    hashCode = hashCode * 59 + this.SummaryLong.GetHashCode();
                if (this.SunTransit != null)
                    hashCode = hashCode * 59 + this.SunTransit.GetHashCode();
                if (this.Sunrise != null)
                    hashCode = hashCode * 59 + this.Sunrise.GetHashCode();
                if (this.Sunset != null)
                    hashCode = hashCode * 59 + this.Sunset.GetHashCode();
                if (this.Temp != null)
                    hashCode = hashCode * 59 + this.Temp.GetHashCode();
                if (this.TempMax != null)
                    hashCode = hashCode * 59 + this.TempMax.GetHashCode();
                if (this.TempMin != null)
                    hashCode = hashCode * 59 + this.TempMin.GetHashCode();
                if (this.WindDir != null)
                    hashCode = hashCode * 59 + this.WindDir.GetHashCode();
                if (this.WindSpd != null)
                    hashCode = hashCode * 59 + this.WindSpd.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
