/* 
 * App Weather - A Weather Source API
 *
 * App/Webpage optimized weather data for latitude/longitude points, ZIP/Postal Codes, and OnPoint™ points. The Weather Source App Weather API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate use. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  This API returns current conditions (Nowcast) and a 7-day of daily and hourly forecast. The nowcast and forecasts include limited astronomical data.  The weather icon classes returned by this API correspond to classes used by the open source licensed [Weather Icons](https://developer.weathersourceapis.com/apis/appwx-weather-icons/) font set.      **IMPORTANT:** To authenticate to the Weather Source App Weather API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = IO.Swagger.Client.SwaggerDateConverter;

namespace IO.Swagger.Model
{
    /// <summary>
    /// A postcode location metadata object
    /// </summary>
    [DataContract]
        public partial class PostcodeObj :  IEquatable<PostcodeObj>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodeObj" /> class.
        /// </summary>
        /// <param name="postcode">postcode (required).</param>
        /// <param name="latitude">latitude (required).</param>
        /// <param name="longitude">longitude (required).</param>
        /// <param name="timezone">timezone (required).</param>
        /// <param name="countryCode">countryCode (required).</param>
        /// <param name="countryName">countryName (required).</param>
        /// <param name="subdivCode">subdivCode.</param>
        /// <param name="subdivName">subdivName.</param>
        /// <param name="boundingPoints">boundingPoints (required).</param>
        /// <param name="grid">grid (required).</param>
        /// <param name="elevation">elevation (required).</param>
        public PostcodeObj(string postcode = default(string), float? latitude = default(float?), float? longitude = default(float?), string timezone = default(string), string countryCode = default(string), string countryName = default(string), string subdivCode = default(string), string subdivName = default(string), BoundingPoints boundingPoints = default(BoundingPoints), Grid grid = default(Grid), float? elevation = default(float?))
        {
            // to ensure "postcode" is required (not null)
            if (postcode == null)
            {
                throw new InvalidDataException("postcode is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Postcode = postcode;
            }
            // to ensure "latitude" is required (not null)
            if (latitude == null)
            {
                throw new InvalidDataException("latitude is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Latitude = latitude;
            }
            // to ensure "longitude" is required (not null)
            if (longitude == null)
            {
                throw new InvalidDataException("longitude is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Longitude = longitude;
            }
            // to ensure "timezone" is required (not null)
            if (timezone == null)
            {
                throw new InvalidDataException("timezone is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Timezone = timezone;
            }
            // to ensure "countryCode" is required (not null)
            if (countryCode == null)
            {
                throw new InvalidDataException("countryCode is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.CountryCode = countryCode;
            }
            // to ensure "countryName" is required (not null)
            if (countryName == null)
            {
                throw new InvalidDataException("countryName is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.CountryName = countryName;
            }
            // to ensure "boundingPoints" is required (not null)
            if (boundingPoints == null)
            {
                throw new InvalidDataException("boundingPoints is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.BoundingPoints = boundingPoints;
            }
            // to ensure "grid" is required (not null)
            if (grid == null)
            {
                throw new InvalidDataException("grid is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Grid = grid;
            }
            // to ensure "elevation" is required (not null)
            if (elevation == null)
            {
                throw new InvalidDataException("elevation is a required property for PostcodeObj and cannot be null");
            }
            else
            {
                this.Elevation = elevation;
            }
            this.SubdivCode = subdivCode;
            this.SubdivName = subdivName;
        }
        
        /// <summary>
        /// Gets or Sets Postcode
        /// </summary>
        [DataMember(Name="postcode", EmitDefaultValue=false)]
        public string Postcode { get; set; }

        /// <summary>
        /// Gets or Sets Latitude
        /// </summary>
        [DataMember(Name="latitude", EmitDefaultValue=false)]
        public float? Latitude { get; set; }

        /// <summary>
        /// Gets or Sets Longitude
        /// </summary>
        [DataMember(Name="longitude", EmitDefaultValue=false)]
        public float? Longitude { get; set; }

        /// <summary>
        /// Gets or Sets Timezone
        /// </summary>
        [DataMember(Name="timezone", EmitDefaultValue=false)]
        public string Timezone { get; set; }

        /// <summary>
        /// Gets or Sets CountryCode
        /// </summary>
        [DataMember(Name="countryCode", EmitDefaultValue=false)]
        public string CountryCode { get; set; }

        /// <summary>
        /// Gets or Sets CountryName
        /// </summary>
        [DataMember(Name="countryName", EmitDefaultValue=false)]
        public string CountryName { get; set; }

        /// <summary>
        /// Gets or Sets SubdivCode
        /// </summary>
        [DataMember(Name="subdivCode", EmitDefaultValue=false)]
        public string SubdivCode { get; set; }

        /// <summary>
        /// Gets or Sets SubdivName
        /// </summary>
        [DataMember(Name="subdivName", EmitDefaultValue=false)]
        public string SubdivName { get; set; }

        /// <summary>
        /// Gets or Sets BoundingPoints
        /// </summary>
        [DataMember(Name="boundingPoints", EmitDefaultValue=false)]
        public BoundingPoints BoundingPoints { get; set; }

        /// <summary>
        /// Gets or Sets Grid
        /// </summary>
        [DataMember(Name="grid", EmitDefaultValue=false)]
        public Grid Grid { get; set; }

        /// <summary>
        /// Gets or Sets Elevation
        /// </summary>
        [DataMember(Name="elevation", EmitDefaultValue=false)]
        public float? Elevation { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class PostcodeObj {\n");
            sb.Append("  Postcode: ").Append(Postcode).Append("\n");
            sb.Append("  Latitude: ").Append(Latitude).Append("\n");
            sb.Append("  Longitude: ").Append(Longitude).Append("\n");
            sb.Append("  Timezone: ").Append(Timezone).Append("\n");
            sb.Append("  CountryCode: ").Append(CountryCode).Append("\n");
            sb.Append("  CountryName: ").Append(CountryName).Append("\n");
            sb.Append("  SubdivCode: ").Append(SubdivCode).Append("\n");
            sb.Append("  SubdivName: ").Append(SubdivName).Append("\n");
            sb.Append("  BoundingPoints: ").Append(BoundingPoints).Append("\n");
            sb.Append("  Grid: ").Append(Grid).Append("\n");
            sb.Append("  Elevation: ").Append(Elevation).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as PostcodeObj);
        }

        /// <summary>
        /// Returns true if PostcodeObj instances are equal
        /// </summary>
        /// <param name="input">Instance of PostcodeObj to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(PostcodeObj input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.Postcode == input.Postcode ||
                    (this.Postcode != null &&
                    this.Postcode.Equals(input.Postcode))
                ) && 
                (
                    this.Latitude == input.Latitude ||
                    (this.Latitude != null &&
                    this.Latitude.Equals(input.Latitude))
                ) && 
                (
                    this.Longitude == input.Longitude ||
                    (this.Longitude != null &&
                    this.Longitude.Equals(input.Longitude))
                ) && 
                (
                    this.Timezone == input.Timezone ||
                    (this.Timezone != null &&
                    this.Timezone.Equals(input.Timezone))
                ) && 
                (
                    this.CountryCode == input.CountryCode ||
                    (this.CountryCode != null &&
                    this.CountryCode.Equals(input.CountryCode))
                ) && 
                (
                    this.CountryName == input.CountryName ||
                    (this.CountryName != null &&
                    this.CountryName.Equals(input.CountryName))
                ) && 
                (
                    this.SubdivCode == input.SubdivCode ||
                    (this.SubdivCode != null &&
                    this.SubdivCode.Equals(input.SubdivCode))
                ) && 
                (
                    this.SubdivName == input.SubdivName ||
                    (this.SubdivName != null &&
                    this.SubdivName.Equals(input.SubdivName))
                ) && 
                (
                    this.BoundingPoints == input.BoundingPoints ||
                    (this.BoundingPoints != null &&
                    this.BoundingPoints.Equals(input.BoundingPoints))
                ) && 
                (
                    this.Grid == input.Grid ||
                    (this.Grid != null &&
                    this.Grid.Equals(input.Grid))
                ) && 
                (
                    this.Elevation == input.Elevation ||
                    (this.Elevation != null &&
                    this.Elevation.Equals(input.Elevation))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.Postcode != null)
                    hashCode = hashCode * 59 + this.Postcode.GetHashCode();
                if (this.Latitude != null)
                    hashCode = hashCode * 59 + this.Latitude.GetHashCode();
                if (this.Longitude != null)
                    hashCode = hashCode * 59 + this.Longitude.GetHashCode();
                if (this.Timezone != null)
                    hashCode = hashCode * 59 + this.Timezone.GetHashCode();
                if (this.CountryCode != null)
                    hashCode = hashCode * 59 + this.CountryCode.GetHashCode();
                if (this.CountryName != null)
                    hashCode = hashCode * 59 + this.CountryName.GetHashCode();
                if (this.SubdivCode != null)
                    hashCode = hashCode * 59 + this.SubdivCode.GetHashCode();
                if (this.SubdivName != null)
                    hashCode = hashCode * 59 + this.SubdivName.GetHashCode();
                if (this.BoundingPoints != null)
                    hashCode = hashCode * 59 + this.BoundingPoints.GetHashCode();
                if (this.Grid != null)
                    hashCode = hashCode * 59 + this.Grid.GetHashCode();
                if (this.Elevation != null)
                    hashCode = hashCode * 59 + this.Elevation.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
